__title__ = 'embedly-cards'
__version__ = '0.2.0'
__author__ = 'Josh Izaac'
__credits__ = ["Josh Izaac", ]
__maintainer__ = "Josh Izaac"
__email__ = "josh@iza.ac"
__status__ = "Stable"
__license__ = 'MIT'
__copyright__ = 'Copyright 2014'

from embedly_cards.card_rst import register
from embedly_cards.card_markdown import EmbedlyCardExtension
